==> hs-Stream-0.4.6.1_1.tbz: lib/ghc-7.4.2/cabal/Stream-0.4.6.1/register.sh <==
#!/bin/sh
echo 'name: Stream
version: 0.4.6.1
id: Stream-0.4.6.1-ebd502e2a5cbcf63c22488d39b81b736

license: BSD3
copyright:
maintainer: Wouter Swierstra <wouter.swierstra@gmail.com>
stability: experimental
homepage:
package-url:
synopsis: A library for manipulating infinite lists.
description: This package implements functions, analogous
             to those from Data.List, to create and manipulate
             infinite lists: @data Stream a = Cons a (Stream a)@.
             It provides alternative definitions for those
             Prelude functions that make sense for such streams.
             Note that this package has (almost)
             nothing to do with the work on /Stream Fusion/ by
             Duncan Coutts, Roman Leshchinskiy, and Don Stewart.
category: Data
author: Wouter Swierstra <wouter.swierstra@gmail.com>
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
exposed-modules: Data.Stream
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/Stream-0.4.6.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/Stream-0.4.6.1
              /usr/local/lib
hs-libraries: HSStream-0.4.6.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.5.1.1-afeb3895324ee60cc5b4d153a73647dc
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         lazysmallcheck-0.6-835146cb07c64f49c318ae6f7b31bd40
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/Stream-0.4.6.1/html/Stream.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/Stream-0.4.6.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-Stream-0.4.6_2.tbz: lib/ghc-7.4.1/cabal/Stream-0.4.6/register.sh <==
#!/bin/sh
echo 'name: Stream
version: 0.4.6
id: Stream-0.4.6-ec7923eb28cda75109786a7ddc7d66da

license: BSD3
copyright:
maintainer: Wouter Swierstra <wss@cs.nott.ac.uk>
stability: experimental
homepage:
package-url:
synopsis: A library for manipulating infinite lists.
description: This package implements functions, analogous
             to those from Data.List, to create and manipulate
             infinite lists: @data Stream a = Cons a (Stream a)@.
             It provides alternative definitions for those
             Prelude functions that make sense for such streams.
             Note that this package has (almost)
             nothing to do with the work on /Stream Fusion/ by
             Duncan Coutts, Roman Leshchinskiy, and Don Stewart.
category: Data
author: Wouter Swierstra <wouter.swierstra@gmail.com>
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
exposed-modules: Data.Stream
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/Stream-0.4.6
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/Stream-0.4.6
              /usr/local/lib
hs-libraries: HSStream-0.4.6
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: QuickCheck-2.4.2-5e1b443b0b725755bf380173d85ffb73
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         lazysmallcheck-0.6-49a7e994e609104db41293c390f97480
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/Stream-0.4.6/html/Stream.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/Stream-0.4.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
